package org.apache.xindice;

/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xindice" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999-2001, The dbXML
 * Group, L.L.C., http://www.dbxmlgroup.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 * $Id: Debug.java,v 1.1.1.1 2001/12/06 19:33:53 bradford Exp $
 */

import org.apache.xindice.util.*;
import java.io.*;

/**
 * Debug is a debugging class for the Xindice Server.  Because the class
 * and the Debugging field are final, the Java compiler should always
 * inline the methods and optimize them away if Debugging is set to false.
 */

public final class Debug {
   public static final boolean Debugging = true;
   
   private static String prefix = "\u0007DEBUG> ";
   private static PrintStream out = System.err;

   public static void SetPrintStream(PrintStream out) {
      Debug.out = out;
   }

   public static void println(Object obj, Object message) {
      if ( Debugging ) {
         if ( obj instanceof Named )
            out.println(prefix+((Named)obj).getName()+": "+message);
         else {
            out.println(prefix+message);
            out.println(" @ "+obj);
         }
      }
   }

   public static void println(Object message) {
      if ( Debugging )
         out.println(prefix+message);
   }

   public static void println() {
      if ( Debugging )
         out.println(prefix);
   }
   
   
   public static void printStackTrace(Throwable t) {
      if ( Debugging ) {
         out.println(prefix);
         t.printStackTrace(out);
      }
   }
   
   public static void setPrintStream(PrintStream outStream) {
      out = outStream;
   }
   
   public static void setPrefix(String debugPrefix) {
      prefix = debugPrefix;
   }
}
