package org.apache.xindice.core.xupdate;

/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xindice" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999-2001, The dbXML
 * Group, L.L.C., http://www.dbxmlgroup.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 * $Id: XUpdateQueryResolver.java,v 1.2 2002/01/16 09:48:39 kstaken Exp $
 */

import org.apache.xindice.core.*;
import org.apache.xindice.core.data.*;
import org.apache.xindice.core.query.*;
import org.apache.xindice.core.xupdate.*;
import org.apache.xindice.util.*;

import org.apache.xindice.xml.*;
import org.apache.xindice.xml.dom.*;

import org.w3c.dom.*;

/**
 * XUpdateQueryResolver
 */

public final class XUpdateQueryResolver extends SimpleConfigurable implements QueryResolver {
   private static final String XUPDATE_XPATH_PROP = "org.infozone.tools.xml.queries.XPathQueryFactory";
   private static final String XUPDATE_XPATH_IMPL = "org.apache.xindice.core.xupdate.XPathQueryFactoryImpl";
   static {
      System.setProperty (XUPDATE_XPATH_PROP, XUPDATE_XPATH_IMPL);
   }

   public static final String STYLE_XUPDATE = "XUpdate";

   private QueryEngine engine;

   public void setConfig(Configuration config) throws XindiceException {
      super.setConfig(config);
   }

   public String getQueryStyle() {
      return STYLE_XUPDATE;
   }

   public void setQueryEngine(QueryEngine engine) {
      this.engine = engine;
   }

   public Query compileQuery(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException {
      return new XUpdateQuery(context, query, nsMap, keys);
   }
   
   public NodeSet query(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException {
      XUpdateQuery xq = new XUpdateQuery(context, query, nsMap, keys);
      return xq.execute();
   }
   

   /**
    * XUpdateQuery
    */

   private class XUpdateQuery implements Query {
      public Collection context;
      public String query;
      public NamespaceMap nsMap;
      public XUpdateImpl xu;
      public Key[] keys;

      public XUpdateQuery(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException {
         this.context = context;
         this.query = query;
         this.nsMap = nsMap;
         this.keys = keys;

         try {
            xu = new XUpdateImpl();
            xu.setQString(query);
            xu.setNamespaceMap(nsMap);
         }
         catch ( Exception e ) {
            throw new CompilationException("Error Compiling XUpdate Query");
         }
      }

      public String getQueryStyle() {
         return STYLE_XUPDATE;
      }

      public Collection getQueryContext() {
         return context;
      }
      
      public String getQueryString() {
         return query;
      }
      
      public NamespaceMap getNamespaceMap() {
         return nsMap;
      }
      
      public Key[] getKeySet() {
         return keys;
      }

      public NodeSet execute() throws QueryException {
         try {
            if ( keys != null ) {
               try {
                  for ( int i = 0; i < keys.length; i++ ) {
                     Document doc = context.getDocument(keys[i]);
                     xu.execute(doc.getDocumentElement());
                     context.setDocument(keys[i], doc);
                  }
               }
               catch ( Exception e ) {
                  org.apache.xindice.Debug.printStackTrace(e);
               }
            }
            else
               xu.execute(context);
            
            DocumentImpl doc = new DocumentImpl();
            Element elem = doc.createElementNS(NodeSource.SOURCE_NS, "src:"+NodeSource.SOURCE_MODIFIED);
            elem.setAttribute(NodeImpl.XMLNS_PREFIX+":src", NodeSource.SOURCE_NS);
            doc.appendChild(elem);
            Text count = doc.createTextNode(Integer.toString(xu.getModifiedCount()));
            elem.appendChild(count);
            
            return new NodeListSet(doc.getChildNodes());
         }
         catch ( Exception e ) {
            throw new ProcessingException("Error executing XUpdate query");
         }
      }
   }
}

