package org.apache.xindice.tools.command;

/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xindice" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999-2001, The dbXML
 * Group, L.L.C., http://www.dbxmlgroup.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 * $Id: AddCollection.java,v 1.1.1.1 2001/12/06 19:33:57 bradford Exp $
 */

import java.util.Hashtable;

import org.xmldb.api.*;
import org.apache.xindice.client.xmldb.services.*;
import org.apache.xindice.client.xmldb.*;

import org.xmldb.api.base.*;
import org.xmldb.api.DatabaseManager;

import org.apache.xindice.xml.dom.*;

import org.w3c.dom.*;

/**
 * AddCollection.java is designed to let the user create
 * new Collections and Nested Collections within the Database.
 */

public class AddCollection extends Command {

   /**
    * TODO: Description of the Method
    *
    * @param table Description of Parameter
    * @return Description of the Returned Value
    * @exception Exception Description of Exception
    */
   public boolean execute(Hashtable table) throws Exception {
      Collection col = null;
      Collection tempcol = null;

      try {

         // Verify that that collection passed in is not null
         if (table.get("collection") != null && table.get("nameOf") != null) {

            // Get a Collection reference to pass on to individual commands
            String colstring = normalizeCollectionURI((String) table.get("collection"));

            col = DatabaseManager.getCollection(colstring);

            if (col == null) {
               System.out.println("ERROR : Collection not found!");
               return false;
            }

            String newcol = (String) table.get("nameOf");

            // Create an instance of the collection manager and create the collection
            try {
               CollectionManager colman = (CollectionManager) col.getService("CollectionManager", XMLDBAPIVERSION);

               String colName = "";
               String parName = newcol;
         
               int idx = parName.lastIndexOf("/");
         
               if (idx != -1) {
                  colName = parName.substring(idx + 1);
                  parName = parName.substring(0, idx);
               }
               else if (idx == -1) {
                  colName = parName;
               }
         
               if (colName.equals("")) {
                  System.out.println("Cannot create a NULL collection");
                  return false;
               }
         
               Document doc = new DocumentImpl();
         
               Element colEle = doc.createElement("collection");
               colEle.setAttribute("compressed", "true");
               colEle.setAttribute("name", colName);
         
               doc.appendChild(colEle);
         
               Element filEle = doc.createElement("filer");
               filEle.setAttribute("class", "org.apache.xindice.core.filer.BTreeFiler");
               //filEle.setAttribute("gzip", "true");
               if ( table.containsKey("pagesize") ) {
                  filEle.setAttribute("pagesize", (String)table.get("pagesize"));
               }

               if (table.containsKey("maxkeysize") ) {
                  filEle.setAttribute("maxkeysize", (String)table.get("maxkeysize") );
               }
               
               colEle.appendChild(filEle);
               
               tempcol = colman.createCollection(newcol, doc);
            }
            catch (Exception e) {
               System.out.println("ERROR : " + e.getMessage());
               return false;
            }

            System.out.println("Created : " + table.get("collection") + "/" + newcol);
         }
         else {
            System.out.println("ERROR : Collection Context and New Collection name required");
         }
      }

      catch (Exception e) {
         System.out.println("ERROR : " + e.getMessage());
         if (table.get("verbose").equals("true")) {
            org.apache.xindice.Debug.printStackTrace(e);
         }
         return false;
      }
      finally {
         // Release the collection objects
         if (col != null) {
            col.close();
         }
         if (tempcol != null) {
            tempcol.close();
         }
      }

      return true;
   }
}



